@@ -464,22 +464,22 @@ VALIDATE_RULES:
 				break VALIDATE_RULES
 			}
 		case strings.HasPrefix(rule, "MinSize("):
-			min, _ := strconv.Atoi(rule[8 : len(rule)-1])
-			if str, ok := fieldValue.(string); ok && utf8.RuneCountInString(str) < min {
+			minSize, _ := strconv.Atoi(rule[8 : len(rule)-1])
+			if str, ok := fieldValue.(string); ok && utf8.RuneCountInString(str) < minSize {
 				errors.Add([]string{field.Name}, ERR_MIN_SIZE, "MinSize")
 				break VALIDATE_RULES
 			}
-			if fieldVal.Kind() == reflect.Slice && fieldVal.Len() < min {
+			if fieldVal.Kind() == reflect.Slice && fieldVal.Len() < minSize {
 				errors.Add([]string{field.Name}, ERR_MIN_SIZE, "MinSize")
 				break VALIDATE_RULES
 			}
 		case strings.HasPrefix(rule, "MaxSize("):
-			max, _ := strconv.Atoi(rule[8 : len(rule)-1])
-			if str, ok := fieldValue.(string); ok && utf8.RuneCountInString(str) > max {
+			maxSize, _ := strconv.Atoi(rule[8 : len(rule)-1])
+			if str, ok := fieldValue.(string); ok && utf8.RuneCountInString(str) > maxSize {
 				errors.Add([]string{field.Name}, ERR_MAX_SIZE, "MaxSize")
 				break VALIDATE_RULES
 			}
-			if fieldVal.Kind() == reflect.Slice && fieldVal.Len() > max {
+			if fieldVal.Kind() == reflect.Slice && fieldVal.Len() > maxSize {
 				errors.Add([]string{field.Name}, ERR_MAX_SIZE, "MaxSize")
 				break VALIDATE_RULES
 			}
